icalendar.prop.recur.frequency module
=====================================

.. automodule:: icalendar.prop.recur.frequency
   :ignore-module-all:
   :members:
   :show-inheritance:
   :undoc-members:
